/* dc_gui2 - a GTK+2 GUI for DCTC
 * Copyright (C) 2002 Eric Prevoteau
 *
 * dctc_process.h: Copyright (C) Eric Prevoteau <www@ac2i.tzo.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
/*
$Id: dctc_process.h,v 1.1.1.1 2003/07/23 05:57:03 ericprev Exp $
*/

#ifndef __DCTC_PROCESS_H__
#define __DCTC_PROCESS_H__

#include <gdk/gdk.h>

/******************************************************************************/
/* count the number of entry inside the given gchar * array (NULL terminated) */
/******************************************************************************/
int gchar_array_len(gchar **array);

/*************************************************************/
/* close the connection to the current DCTC client if exists */
/*************************************************************/
void close_current_dctc(void);

/***************************************************/
/* delete the array containing the nick of all ops */
/***************************************************/
void clear_op_array(void);

/**********************************************/
/* discard the content of the temp user array */
/**********************************************/
void flush_user_lst_start(void);

/**********************************************************************************/
/* this function is called when something comes from DCTC client                  */
/* data is always NULL, source == current_dctc_fd and condition == GTK_INPUT_READ */
/**********************************************************************************/
void process_data_from_dctc(gpointer data, gint source, GdkInputCondition condition);

/**********************************************************************************/
/* this function is called when something comes from DCTC client                  */
/* data is always NULL, source == current_dctc_fd and condition == GTK_INPUT_READ */
/**********************************************************************************/
/* technically, the function performs exactly the same tasks as the previous one */
/* except it uses gdl_dctc instead of current_dctc *DCTC_COM                     */
/*********************************************************************************/
void process_data_from_gdl_dctc(gpointer data, gint source, GdkInputCondition condition);

/************************************************************************************/
/* same function as previous one except it tries to send queued data to DCTC client */
/************************************************************************************/
void process_data_to_dctc(gpointer data, gint source, GdkInputCondition condition);

/****************************************/
/* send data to the current DCTC client */
/* the function handles all errors      */
/****************************************/
void send_data_to_dctc(char *str);

/************************************/
/* send data to the GDL DCTC client */
/* the function handles all errors  */
/************************************/
void send_data_to_gdl_dctc(char *str);

/************************************************/
/* open password dialog to enter a new password */
/************************************************/
void enter_passwd_fnc(const GString *in);

/*****************************************************************/
/* create autoscan configuration window for selected GDL entries */
/*****************************************************************/
void create_autoscan_window_for_selected_gdl_entry(void);

/*************************************************/
/* create rename window for selected GDL entries */
/*************************************************/
void create_rename_window_for_selected_gdl_entry(void);

/*************************************************/
/* create rename window for selected GDL entries */
/*************************************************/
void create_script_window_for_selected_gdl_entry(void);

/**********************************************/
/* automatically flag the given user nickname */
/**********************************************/
void auto_flag_user(const char *nick);

/**********************************************************************/
/* kill upload or download task using their ID (and /KILL or /KILLKB) */
/**********************************************************************/
void kill_selected_entry(char *cmd,char *clist_name, int clist_row);

/*********************************************************************************************/
/* foreach selected line, send the given command followed by the content of the given column */
/*********************************************************************************************/
void foreach_selected_entry_send_cmd(char *cmd,char *clist_name, int column_num);
void foreach_selected_entry_send_cmd_to_gdl(char *cmd,char *clist_name, int column_num);

/*******************************************************************/
/* return the GTK_TEXT widget of the chat having the LABEL == nick */
/* if nick doesn't have a private chat and create parameter is     */
/* true, the function creates one                                  */
/*******************************************************************/
GtkWidget *get_pchat_text_widget_from_nick(char *nick, gboolean create,char **notebook_label,int *notebook_num);


/***********************************************************************************/
/* when the multihub search is enabled, this function is called after 10 seconds   */
/* if more than 15 results are available, nothing occurs, else a /MSRCH is started */
/***********************************************************************************/
gint start_msearch(gpointer data);

/******************************/
/* end the FLST clist refresh */
/******************************/
void user_share_full_list_fnc(const GString *in);

/************************/
/* reset the xfer lists */
/************************/
/* input: NULL */
/***************/
void begin_xfer_list_fnc(const GString *s);

#endif
